/*
   Copyright (C) 2009 Erik Lax 

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.

   In addition, as a special exception, the copyright holders give
   permission to link the code of portions of this program with the
   OpenSSL library under certain conditions as described in each
   individual source file, and distribute linked combinations
   including the two.
   You must obey the GNU General Public License in all respects
   for all of the code used other than OpenSSL. If you modify
   file(s) with this exception, you may extend this exception to your
   version of the file(s), but you are not obligated to do so. If you
   do not wish to do so, delete this exception statement from your
   version. If you delete this exception statement from all source
   files in the program, then also delete it here.
*/

#ifndef _XVA_DISK_HPP_
#define _XVA_DISK_HPP_

#include <string>
#include <stdexcept>

namespace XVA {
	class Disk
	{
		public:
			Disk(const std::string& path);
			bool Export(const std::string& diskpath)
				noexcept(false);
			bool Import(const std::string& diskpath)
				noexcept(false);

			void Verbose();
			void Sparse();
			void IgnoreChecksum();
		private:
			std::string m_path;
			bool m_verbose;
			bool m_sparse;
			bool m_ignore_checksum;
	};
}

#endif
